@@ -2,6 +2,7 @@ from typing import List
 
 from discordmenu.embed.components import EmbedMain
 from discordmenu.embed.view import EmbedView
+from tsutils.query_settings.query_settings import QuerySettings
 
 from tsutils.menu.components.config import UserConfig
 from tsutils.menu.components.footers import embed_footer_with_state
@@ -10,18 +11,19 @@ from tsutils.menu.view.view_state_base import ViewStateBase
 
 class SimpleTextViewState(ViewStateBase):
     def __init__(self, original_author_id, menu_type, raw_query,
-                 color, message,
+                 query_settings: QuerySettings, message,
                  reaction_list: List[str] = None,
                  extra_state=None):
         super().__init__(original_author_id, menu_type, raw_query,
                          reaction_list=reaction_list, extra_state=extra_state)
         self.message = message
-        self.color = color
+        self.query_settings = query_settings
 
     def serialize(self):
         ret = super().serialize()
         ret.update({
             'message': self.message,
+            'query_settings': self.query_settings.serialize(),
         })
         return ret
 
@@ -30,7 +32,8 @@ class SimpleTextViewState(ViewStateBase):
         original_author_id = ims['original_author_id']
         menu_type = ims['menu_type']
         raw_query = ims.get('raw_query')
-        return cls(original_author_id, menu_type, raw_query, user_config.color, ims.get('message'),
+        query_settings = QuerySettings.deserialize(ims.get('query_settings'))
+        return cls(original_author_id, menu_type, raw_query, query_settings, ims.get('message'),
                    reaction_list=ims.get('reaction_list'), extra_state=ims)
 
 
@@ -41,7 +44,7 @@ class SimpleTextView:
     def embed(state: SimpleTextViewState):
         return EmbedView(
             EmbedMain(
-                color=state.color,
+                color=state.query_settings.color,
                 description=state.message
             ),
             embed_footer=embed_footer_with_state(state),
